@@ -32,6 +32,7 @@ sub start_gui {
         destroy => sub {
             $window->destroy;
             Gtk2->main_quit;
+            1;
         }
     );
     $window->signal_connect(
@@ -149,7 +150,7 @@ sub startup {
         $message      = _( 'Updates are available' );
         $message_type = 'warning';
     } elsif ( $startup_check eq 'sigs' ) {
-        $message      = _( 'The antivirus signatures are out-of-date' );
+        $message      = _( 'The antivirus signatures are outdated' );
         $message_type = 'warning';
     } elsif ( $startup_check eq 'gui' ) {
         $message      = _( 'An update is available' );
@@ -830,7 +831,6 @@ sub about {
     $dialog->set_logo( $pixbuf );
     $dialog->set_version( ClamTk::App->get_TK_version() );
     $dialog->set_license( $license );
-    $dialog->set_wrap_license( TRUE );
     $dialog->set_website_label( _( 'Homepage' ) );
     $dialog->set_website( 'http://code.google.com/p/clamtk/' );
     $dialog->set_logo( $pixbuf );
