@@ -142,7 +142,7 @@ sub view_history {
 
     my $win = Gtk2::Window->new;
     $win->set_title( sprintf( _( 'Viewing %s' ), $basename ) );
-    $win->signal_connect( destroy => sub { $win->destroy } );
+    $win->signal_connect( destroy => sub { $win->destroy; 1 } );
     $win->set_default_size( 800, 350 );
 
     my $textview = Gtk2::TextView->new;
