@@ -52,6 +52,7 @@ my $threats_label;          # Gtk2::Label
 my $show;                   # Whether or not to show the preferences button
 
 my $window;                 # Main window
+my $from_cli;               # from the commandline?
 
 sub filter {
     # $pkg_name = drop this
@@ -60,6 +61,7 @@ sub filter {
     #   we do if it's a commandline or right-click scan; otherwise we don't
     # $from = from the commandline?
     my ( $pkg_name, $scanthis, $show, $from ) = @_;
+    $from_cli = $from;
 
     # Currently just to test permissions:
     # If given a file/directory from the commandline
@@ -95,6 +97,7 @@ sub filter {
                 return TRUE;
             } else {
                 $window->destroy;
+                1;
             }
         }
     );
@@ -470,6 +473,9 @@ sub clean_up {
 
     if ( $found_count ) {
         ClamTk::Results->show_window( $found, $window );
+        if ( $from_cli ) {
+            Gtk2->main_quit;
+        }
     } else {
         bad_popup();
     }
